.. denofo documentation master file, created by
   sphinx-quickstart on Thu Mar 27 17:12:46 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the denofo toolkit documentation!
============================================

Version: |release|

DENOFO Toolkit
==============

.. image:: ../denofo/static/denofo-logo.jpg
   :alt: DENOFO Toolkit
   :align: center
   :width: 50%

DENOFO is a toolkit developed for the de novo gene research community. 
It provides tools for working with a standardized de novo gene annotation format, 
facilitating the annotation, conversion, and comparison of de novo gene annotations.

De Novo Gene Annotation Format (DNGF)
-------------------------------------
.. _de-novo-gene-annotation-format-dngf:

The Denofo toolkit introduces a standardized annotation format for de novo genes. 
This format aims to streamline the annotation process and ensure consistency 
across different studies and methodologies used to detect de novo genes. 
The ``*.dngf`` file extension is used for these annotation files.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tools
   installation
   usage
   technical_documentation
   ncbi_tax_db
   contributing
   citation



.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
